import React, { useEffect } from "react";
import { Helmet } from "react-helmet";
import Navbar from "@/components/Navbar";
import Footer from "@/components/Footer";
import { Button } from "@/components/ui/button";
import { CheckCircle } from "lucide-react";
import { Link } from "react-router-dom";

const AboutUs = () => {
  useEffect(() => {
    window.scrollTo(0, 0);
  }, []);

  return (
    <div className="flex flex-col min-h-screen">
      <Helmet>
        <title>About Us | FTFX Tech Solutions</title>
        <meta name="description" content="Learn about FTFX Tech Solutions and our mission to provide exceptional technology support services." />
      </Helmet>

      <Navbar />

      <main className="flex-grow">
        {/* Hero Section */}
        <section className="bg-ftfx-dark-bg pt-28 pb-16 md:pt-32 md:pb-20 relative overflow-hidden">
          <div className="absolute top-0 left-1/2 -translate-x-1/2 w-full max-w-6xl h-[500px] bg-ftfx-purple/10 rounded-full blur-[120px] -z-10"></div>
          
          <div className="container mx-auto px-4 md:px-6">
            <div className="text-center">
              <h1 className="text-3xl md:text-4xl lg:text-5xl font-bold mb-6">
                About <span className="text-gradient">FTFX</span> Tech Solutions
              </h1>
              <p className="text-lg text-gray-300 mb-8 max-w-2xl mx-auto">
                We're on a mission to make technology work for you, not against you.
              </p>
            </div>
          </div>
        </section>

        {/* Our Story Section */}
        <section className="bg-ftfx-card-bg py-16 md:py-24">
          <div className="container mx-auto px-4 md:px-6">
            <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 items-center">
              <div>
                <h2 className="text-3xl font-bold mb-6">Our <span className="text-ftfx-purple">Story</span></h2>
                <p className="text-gray-300 mb-4">
                  FTFX Tech Solutions was founded in 2018 with a simple yet powerful vision: to provide technology solutions that actually solve problems for real people and businesses.
                </p>
                <p className="text-gray-300 mb-4">
                  After years of working in corporate IT environments, our founder recognized a significant gap in the market. Most tech support services were either too complicated, too expensive, or simply not focused on what clients actually needed.
                </p>
                <p className="text-gray-300">
                  We built FTFX Tech Solutions to bridge that gap – offering accessible, human-centered technology support that prioritizes your needs, explains complex concepts in simple language, and delivers sustainable solutions rather than quick fixes.
                </p>
              </div>
              
              <div className="relative">
                <div className="bg-ftfx-accent-bg p-3 rounded-xl shadow-xl border border-ftfx-purple/30">
                  <img 
                    src="https://images.unsplash.com/photo-1552664730-d307ca884978?auto=format&fit=crop&q=80&w=1800"
                    alt="FTFX Team" 
                    className="rounded-lg w-full h-auto object-cover aspect-video"
                    loading="lazy"
                  />
                </div>
                <div className="absolute -bottom-5 -right-5 bg-ftfx-card-bg p-4 rounded-lg shadow-lg border border-ftfx-purple/30 max-w-[220px]">
                  <p className="text-sm font-medium">
                    "Technology made simple, support made human."
                  </p>
                  <p className="text-xs text-gray-400 mt-2">— Our guiding principle</p>
                </div>
              </div>
            </div>
          </div>
        </section>

        {/* Mission & Values Section */}
        <section className="bg-ftfx-dark-bg py-16 md:py-24">
          <div className="container mx-auto px-4 md:px-6">
            <div className="text-center mb-12">
              <h2 className="text-3xl font-bold mb-4">Our Mission & <span className="text-ftfx-purple">Values</span></h2>
              <p className="text-lg text-gray-400 max-w-2xl mx-auto">
                We're guided by a set of core principles that inform everything we do.
              </p>
            </div>
            
            <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
              <ValueCard 
                title="Client-First Approach"
                description="We prioritize your needs and goals above all else, designing solutions that work for your specific situation."
              />
              <ValueCard 
                title="Clear Communication"
                description="We explain technical concepts in plain language and keep you informed throughout every process."
              />
              <ValueCard 
                title="Continuous Learning"
                description="Technology evolves rapidly, and so do we. We're committed to staying ahead of the curve."
              />
              <ValueCard 
                title="Ethical Practices"
                description="We recommend only what you need, never upselling unnecessary services or products."
              />
              <ValueCard 
                title="Long-term Solutions"
                description="We focus on sustainable fixes and proactive measures, not just temporary patches."
              />
              <ValueCard 
                title="Accessibility"
                description="We believe quality tech support should be available to everyone, regardless of technical background."
              />
            </div>
          </div>
        </section>

        {/* Why Choose Us Section */}
        <section className="bg-ftfx-card-bg py-16 md:py-24">
          <div className="container mx-auto px-4 md:px-6">
            <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 items-center">
              <div>
                <h2 className="text-3xl font-bold mb-6">Why Choose <span className="text-ftfx-purple">FTFX</span>?</h2>
                
                <div className="space-y-6">
                  <BenefitItem 
                    title="Expert Team" 
                    description="Our specialists have extensive experience across all aspects of modern technology."
                  />
                  <BenefitItem 
                    title="Personalized Solutions" 
                    description="We don't offer one-size-fits-all packages. Every solution is tailored to your specific needs."
                  />
                  <BenefitItem 
                    title="Transparent Pricing" 
                    description="No hidden fees or unexpected costs. We're upfront about what you'll pay."
                  />
                  <BenefitItem 
                    title="Ongoing Support" 
                    description="Our relationship doesn't end after implementation. We're here for you long-term."
                  />
                  <BenefitItem 
                    title="Proactive Approach" 
                    description="We identify and address potential issues before they become problems."
                  />
                </div>
              </div>
              
              <div className="grid grid-cols-2 gap-4">
                <div className="bg-ftfx-card-bg p-2 rounded-xl shadow-md border border-ftfx-purple/20">
                  <img 
                    src="https://images.unsplash.com/photo-1519389950473-47ba0277781c?auto=format&fit=crop&q=80&w=1800"
                    alt="Team collaboration" 
                    className="rounded-lg w-full h-64 sm:h-72 object-cover"
                    loading="lazy"
                  />
                </div>
                <div className="bg-ftfx-card-bg p-2 rounded-xl shadow-md border border-ftfx-purple/20 mt-8">
                  <img 
                    src="https://images.unsplash.com/photo-1521737711867-e3b97375f902?auto=format&fit=crop&q=80&w=1800"
                    alt="Client meeting" 
                    className="rounded-lg w-full h-64 sm:h-72 object-cover"
                    loading="lazy"
                  />
                </div>
                <div className="bg-ftfx-card-bg p-2 rounded-xl shadow-md border border-ftfx-purple/20">
                  <img 
                    src="https://images.unsplash.com/photo-1522071820081-009f0129c71c?auto=format&fit=crop&q=80&w=1800"
                    alt="Team working" 
                    className="rounded-lg w-full h-64 sm:h-72 object-cover"
                    loading="lazy"
                  />
                </div>
                <div className="bg-ftfx-card-bg p-2 rounded-xl shadow-md border border-ftfx-purple/20 mt-8">
                  <img 
                    src="https://images.unsplash.com/photo-1542744173-8e7e53415bb0?auto=format&fit=crop&q=80&w=1800"
                    alt="Business presentation" 
                    className="rounded-lg w-full h-64 sm:h-72 object-cover"
                    loading="lazy"
                  />
                </div>
              </div>
            </div>
          </div>
        </section>

        {/* CTA Section */}
        <section className="bg-gradient-to-r from-ftfx-dark-purple to-ftfx-purple py-16 md:py-20">
          <div className="container mx-auto px-4 md:px-6 text-center">
            <h2 className="text-3xl md:text-4xl font-bold text-white mb-6">
              Ready to Work With Us?
            </h2>
            <p className="text-lg text-white/80 mb-8 max-w-2xl mx-auto">
              Contact us today to discuss how we can help with your technology challenges.
            </p>
            <Link to="/contact-us">
              <Button className="bg-white text-ftfx-purple hover:bg-gray-100 px-8 py-6 text-lg font-medium">
                Get in Touch
              </Button>
            </Link>
          </div>
        </section>
      </main>

      <Footer />
    </div>
  );
};

interface ValueCardProps {
  title: string;
  description: string;
}

const ValueCard = ({ title, description }: ValueCardProps) => (
  <div className="bg-ftfx-accent-bg p-6 rounded-xl border border-ftfx-dark-purple/20 shadow-md hover:shadow-lg hover:shadow-ftfx-purple/20 hover:-translate-y-1 transition-all duration-300">
    <h3 className="text-xl font-bold mb-3">{title}</h3>
    <p className="text-gray-400">{description}</p>
  </div>
);

interface BenefitItemProps {
  title: string;
  description: string;
}

const BenefitItem = ({ title, description }: BenefitItemProps) => (
  <div className="flex gap-4">
    <div className="flex-shrink-0 mt-1">
      <CheckCircle className="h-6 w-6 text-ftfx-purple" />
    </div>
    <div>
      <h3 className="text-lg font-semibold mb-1">{title}</h3>
      <p className="text-gray-400">{description}</p>
    </div>
  </div>
);

export default AboutUs;
